"""
Django settings for viralhostrange project.

Generated by 'django-admin startproject' using Django 2.1.7.

For more information on this file, see
https://docs.djangoproject.com/en/2.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.1/ref/settings/
"""

import os

from decouple import config
# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
from django.utils.translation import ugettext_lazy

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
from basetheme_bootstrap import db_finder

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = config('SECRET_KEY')

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = config('DEBUG', default=False, cast=bool)

ALLOWED_HOSTS = [s.strip() for s in config('ALLOWED_HOSTS').split(',')]

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_crontab',
    'rest_framework',
    'crispy_forms',
    'basetheme_bootstrap',
    'viralhostrangedb',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'viralhostrange.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'basetheme_bootstrap.context_processors.processors',
            ],
        },
    },
]

WSGI_APPLICATION = 'viralhostrange.wsgi.application'

# Database
# https://docs.djangoproject.com/en/2.1/ref/settings/#databases

if config('USE_SQLITE_AS_DB', default=False, cast=bool):
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': os.path.join(BASE_DIR, 'persistent_volume', 'db.sqlite3'),
        }
    }
else:
    if os.environ.get('POSTGRES_PASSWORD', '') == '':
        DATABASES_HOST = db_finder.get_db_ip()
    else:
        DATABASES_HOST = 'db'
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql',
            'NAME': 'postgres',
            'USER': 'postgres',
            'PASSWORD': config('POSTGRES_PASSWORD'),
            'HOST': DATABASES_HOST,
            'PORT': 5432,
        }
    }
print(DATABASES['default']['ENGINE'])
# Password validation
# https://docs.djangoproject.com/en/2.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

# Internationalization
# https://docs.djangoproject.com/en/2.1/topics/i18n/

LANGUAGE_CODE = 'en-us'
LOCALE_PATHS = [
    os.path.join(BASE_DIR, 'locale/'),
]
LANGUAGES = [
    ('en', ugettext_lazy('English')),
    ('fr', ugettext_lazy('French')),
]

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.1/howto/static-files/


STATIC_ROOT = os.path.join(BASE_DIR, '.static')
STATIC_URL = config('STATIC_URL', default='/static') + '/'
MEDIA_ROOT = os.path.join(BASE_DIR, '.media')

################################################################################
# DRF
################################################################################
REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': (
        'rest_framework.authentication.BasicAuthentication',
        'rest_framework.authentication.SessionAuthentication',
    )
}

################################################################################
# django-crispy-forms
################################################################################
CRISPY_TEMPLATE_PACK = 'bootstrap4'

################################################################################
# basetheme_bootstrap
################################################################################
BASETHEME_BOOTSTRAP_TEMPLATE_LOCATION_PROJECT = "viralhostrangedb"
BASETHEME_BOOTSTRAP_USER_PREFERENCE_MODEL_ENABLED = False
BASETHEME_BOOTSTRAP_USER_PREFERENCE_MODEL_LOCATION_APP = "viralhostrangedb"

################################################################################
# EMAIL
################################################################################
EMAIL_HOST = config('EMAIL_HOST', default='smtp.pasteur.fr')
EMAIL_PORT = config('EMAIL_PORT', default='587')
EMAIL_USE_TLS = config('EMAIL_USE_TLS', default='True')
DEFAULT_FROM_EMAIL = config('DEFAULT_FROM_EMAIL', default='noreply@viralhostrangedb.pasteur.cloud')
EMAIL_SUBJECT_PREFIX = config('DEFAULT_FROM_EMAIL', default='[TinyTracker]')
EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'

################################################################################
# Uploading files
################################################################################
FILE_UPLOAD_HANDLERS = [
    "django.core.files.uploadhandler.MemoryFileUploadHandler",
    "django.core.files.uploadhandler.TemporaryFileUploadHandler",
]

################################################################################
