from django.apps import apps
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from basetheme_bootstrap.admin import ViewOnSiteModelAdmin
from viralhostrangedb import models


@admin.register(models.DataSource)
class DataSourceAdmin(ViewOnSiteModelAdmin):
    list_display = (
        'owner',
        'public',
        'name',
        'creation_date',
        'last_edition_date',
    )
    list_filter = (
        'public',
        'owner',
    )
    filter_horizontal = (
        'allowed_users',
    )
    date_hierarchy = 'creation_date'


@admin.register(models.Virus, models.Strain)
class VirusStrainAdmin(ViewOnSiteModelAdmin):
    list_display = (
        'name',
    )
    list_filter = (
        'data_source',
    )
    filter_horizontal = (
        'data_source',
    )


@admin.register(models.ViralStrainResponseValueInDataSource)
class ViralStrainResponseValueInDataSourceAdmin(ViewOnSiteModelAdmin):
    list_display = (
        'raw_response',
        'virus_name',
        'strain_name',
        'response',
    )
    list_filter = (
        'response',
    )

    def virus_name(self, o):
        return o.virus.name

    def strain_name(self, o):
        return o.strain.name


for model in apps.get_app_config('viralhostrangedb').models.values():
    try:
        admin.site.register(model)
    except admin.sites.AlreadyRegistered as are:
        continue

admin.site.site_header = _('ViralHostRangeDB website administration')

admin.site.site_title = admin.site.site_header

admin.site.index_header = _('ViralHostRangeDB administration')

admin.site.index_title = admin.site.index_header
