import csv
from collections import namedtuple

import pandas as pd
from django.db import transaction
from django.utils import timezone

from viralhostrangedb import models

ViralStrainResponse = namedtuple("ViralStrainResponse", ["virus", "strain", "response"])


def parse_file(file):
    content = pd.read_excel(file, index_col=0, header=0)
    my_reader = csv.reader(content.to_csv(sep=';').split('\n'), delimiter=';')
    header = None
    start_at = 0
    for row in my_reader:
        sub_row = row[start_at:]
        for id_col, cell in enumerate(sub_row):
            if header is None:
                if cell is not "" and not cell.startswith("Unnamed: "):
                    header = row
                    start_at = id_col - 1
                    break
            elif id_col > 0:
                yield ViralStrainResponse(virus=sub_row[0], strain=header[id_col + start_at], response=cell)


def to_dict(viral_strain_responses):
    data_as_dict = {}
    for vhr in viral_strain_responses:
        strain_dict = data_as_dict.setdefault(vhr.strain, dict())
        strain_dict[vhr.virus] = vhr.response
    return data_as_dict


@transaction.atomic
def import_file(*, data_source, file):
    not_mapped_yet = models.GlobalViralStrainResponseValue.get_not_mapped_yet()
    virus_dict = dict()
    strain_dict = dict()
    for vhr in parse_file(file):
        try:
            virus = virus_dict[vhr.virus]
        except KeyError:
            virus = models.Virus.objects.create(
                name=vhr.virus,
            )
            virus.data_source.add(data_source),
            virus_dict[vhr.virus] = virus
        try:
            strain = strain_dict[vhr.strain]
        except KeyError:
            strain = models.Strain.objects.create(
                name=vhr.strain,
            )
            strain.data_source.add(data_source),
            strain_dict[vhr.strain] = strain
        models.ViralStrainResponseValueInDataSource.objects.get_or_create(
            data_source=data_source,
            virus=virus,
            strain=strain,
            raw_response=vhr.response,
            defaults=dict(
                response=not_mapped_yet,
            ),
        )
    data_source.last_edition_date = timezone.now()
    data_source.save()
    return data_source
